# Digitalhub Library

The Digitalhub library is a python tool for managing projects, entities and executions in Digitalhub. It exposes CRUD methods to create, read, update and delete entities, tools to execute functions or workflows, collect or store execution results and data.

A more detailed description of the library can be found in the [official documentation](https://scc-digitalhub.github.io/sdk-docs/).
